@@ -63,7 +63,7 @@ public:
     /**
      * Constructs a message item. It is hidden by default.
      */
-    KGamePopupItem(QGraphicsItem * parent = 0);
+    KGamePopupItem(QGraphicsItem * parent = nullptr);
     /**
      * Destructs a message item
      */
@@ -132,7 +132,7 @@ public:
      */
     void forceHide(HideType type=AnimatedHide);
     /**
-     * Sets brush used to paint item backgound
+     * Sets brush used to paint item background
      * By default system-default brush is used
      * @see KColorScheme
      */
